/*
/////    SAPC APCA - Advanced Perceptual Contrast Algorithm
/////           Beta 0.1.2 W3 ? contrast function only
/////           DIST: W3 ? Revision date: Apr 23, 2022
/////    Function to parse color values and determine Lc contrast
/////    Copyright  2019-2022 by Andrew Somers. All Rights Reserved.
/////    LICENSE: W3 LICENSE
/////    CONTACT: Please use the ISSUES or DISCUSSIONS tab at:
/////    https://github.com/Myndex/SAPC-APCA/
/////
///////////////////////////////////////////////////////////////////////////////
/////
/////    IMPORTS:
/////    import { APCAcontrast, sRGBtoY, displayP3toY,
/////             calcAPCA, fontLookupAPCA } from 'apca-w3';
/////    import { colorParsley } from 'colorparsley';
/////
/////    FORWARD CONTRAST USAGE:
/////    Lc = APCAcontrast( sRGBtoY( TEXTcolor ) , sRGBtoY( BACKGNDcolor ) );
/////    Where the colors are sent as an rgba array [0,0,0,255]
/////
/////    Retrieving an array of font sizes for the contrast:
/////    fontArray = fontLookupAPCA(Lc);
/////
/////
/////    Live Demonstrator at https://www.myndex.com/APCA/
// */
function APCAcontrast(a,b,c){c=void 0===c?-1:c;var d=[0,1.1];if(isNaN(a)||isNaN(b)||Math.min(a,b)<d[0]||Math.max(a,b)>d[1])return 0;d="BoW";a=.022<a?a:a+Math.pow(.022-a,1.414);b=.022<b?b:b+Math.pow(.022-b,1.414);if(5E-4>Math.abs(b-a))return 0;b>a?(a=1.14*(Math.pow(b,.56)-Math.pow(a,.57)),a=.1>a?0:a-.027):(d="WoB",a=1.14*(Math.pow(b,.65)-Math.pow(a,.62)),a=-.1<a?0:a+.027);return 0>c?100*a:0==c?Math.round(100*Math.abs(a))+"<sub>"+d+"</sub>":Number.isInteger(c)?(100*a).toFixed(c):0}
function reverseAPCA(a,b,c,d){a=void 0===a?0:a;b=void 0===b?1:b;c=void 0===c?"bg":c;d=void 0===d?"hex":d;if(5>Math.abs(a))return!1;var f=1/2.4,e=0<a?.027:-.027;a=(.01*parseFloat(a)+e)/1.14;b=.022<b?b:b+Math.pow(.022-b,1.414);if("bg"==c||"background"==c){if(knownExp=0<a?.56:.65,unknownExp=0<a?.57:.62,a=Math.pow(Math.pow(b,knownExp)-a,1/unknownExp),isNaN(a))return!1}else if("txt"==c||"text"==c){if(knownExp=0<a?.57:.62,unknownExp=0<a?.56:.65,a=Math.pow(a+Math.pow(b,knownExp),1/unknownExp),isNaN(a))return!1}else return!1;
if(1.06<a||0>a)return!1;a=.022<a?a:.5136488193988227*Math.pow(1.9468554433171*(a+.0387393816571401),.20038429732734725)-.312865795870758;a=Math.max(Math.min(a,1),0);return"hex"===d?(c=Math.round(255*Math.pow(a,f)).toString(16).padStart(2,"0"),"#"+c+c+c):"color"===d?(d=Math.round(255*Math.pow(a,f)),[d,d,d,1,"bg"==c?"txtColor":"bgColor"]):"Y"===d||"y"===d?Math.max(0,a):!1}
function sRGBtoY(a){a=void 0===a?[0,0,0]:a;return.2126729*Math.pow(a[0]/255,2.4)+.7151522*Math.pow(a[1]/255,2.4)+.072175*Math.pow(a[2]/255,2.4)}function displayP3toY(a){a=void 0===a?[0,0,0]:a;return.228982959480578*Math.pow(a[0],2.4)+.691749262585238*Math.pow(a[1],2.4)+.0792677779341829*Math.pow(a[2],2.4)}function adobeRGBtoY(a){a=void 0===a?[0,0,0]:a;return.297355022711381*Math.pow(a[0]/255,2.35)+.627372749714528*Math.pow(a[1]/255,2.35)+.0752722275740913*Math.pow(a[2]/255,2.35)}
function alphaBlend(a,b,c){a=void 0===a?[0,0,0,1]:a;b=void 0===b?[0,0,0]:b;c=void 0===c?!0:c;a[3]=Math.max(Math.min(a[3],1),0);var d=1-a[3],f=[0,0,0];for(i=0;3>i;i++)f[i]=b[i]*d+a[i]*a[3],c&&(f[i]=Math.min(Math.round(f[i]),255));return f}function calcAPCA(a,b,c,d){c=void 0===c?-1:c;d=void 0===d?!0:d;b=colorParsley(b);a=colorParsley(a);""!=a[3]&&1!=a[3]&&(a=alphaBlend(a,b,d));return APCAcontrast(sRGBtoY(a),sRGBtoY(b),c)}
function fontLookupAPCA(a){var b=[a.toFixed(3),0,0,0,0,0,0,0,0,0];a=Math.abs(a);var c=.2*a|0,d=[["Lc",100,200,300,400,500,600,700,800,900],[0,999,999,999,999,999,999,999,999,999],[10,999,999,999,999,999,999,777,777,777],[15,999,999,777,777,777,777,120,120,120],[20,999,777,777,777,120,120,110,88,66],[25,999,777,777,120,102,87,72,57.5,43],[30,999,777,120,96,68,58,48,38.5,29],[35,777,120,93.5,66,46.5,40,33,26.5,20],[40,777,96,68,48,34,29,24,20,18],[45,120,72,51,36,28,24,20,18,418],[50,96.5,58,41,29,
25,20,18,17,418],[55,86.5,52,37,26,22,19.5,17,16,418],[60,80,48,34,24,21,18,16,416,418],[65,71.5,43,30.5,21.5,19.5,17,15,416,418],[70,65,39,27.5,19.5,18,16,14.5,416,418],[75,60,36,24,18,17,15,14,416,418],[80,56.5,34,23,17,16,14.5,414,416,418],[85,53.5,32,22,16,15,14,414,416,418],[90,50,30,21,15,14.5,414,414,416,418],[95,48.5,29,20.5,14.5,14,414,414,416,418],[100,46.5,28,18,14,414,414,414,416,418],[105,445,427,417,413.5,413.5,413.5,413.5,416,418],[120,445,427,417,413.5,413.5,413.5,413.5,416,418]],
f=[["Lc\u2206h",100,200,300,400,500,600,700,800,900],[0,0,0,0,0,0,0,0,0,0],[10,0,0,0,0,0,0,0,0,0],[15,0,0,0,0,0,0,10,32,54],[20,0,0,0,0,18,33,38,30.5,23],[25,0,0,0,24,34,29,24,19,14],[30,0,0,26.5,30,21.5,18,15,12,9],[35,0,24,25.5,18,12.5,11,9,6.5,2],[40,0,24,17,12,6,5,4,2,0],[45,23.5,14,10,7,3,4,2,1,0],[50,10,6,4,3,3,.5,1,1,0],[55,6.5,4,3,2,1,1.5,1,0,0],[60,8.5,5,3.5,2.5,1.5,1,1,0,0],[65,6.5,4,3,2,1.5,1,.5,0,0],[70,5,3,3.5,1.5,1,1,.5,0,0],[75,3.5,2,1,1,1,.5,0,0,0],[80,3,2,1,1,1,.5,0,0,0],[85,3.5,
2,1,1,.5,0,0,0,0],[90,1.5,1,.5,.5,0,0,0,0,0],[95,2,1,2.5,.5,0,0,0,0,0],[100,1.5,1,1,.5,.5,.5,.5,0,0],[105,0,0,0,0,0,0,0,0,0],[120,0,0,0,0,0,0,0,0,0]],e=0;var h=.2*(a-d[c][e]);for(e++;10>e;e++){var g=d[c][e];400<g?b[e]=g:41>a?b[e]=666:24<g?b[e]=Math.round(g-f[c][e]*h):b[e]=g-.5*(2*f[c][e]*h|0)}return b}module.exports={APCAcontrast:APCAcontrast,sRGBtoY:sRGBtoY,displayP3toY:displayP3toY,adobeRGBtoY:adobeRGBtoY,alphaBlend:alphaBlend,calcAPCA:calcAPCA,fontLookupAPCA:fontLookupAPCA};
